# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Session History Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ApimodelsXRayMatchPoolPodTickResult(Model):
    """Apimodels X ray match pool pod tick result (apimodels.XRayMatchPoolPodTickResult)

    Properties:
        pod_name: (podName) REQUIRED str

        tick_id: (tickId) REQUIRED str

        timestamp: (timestamp) REQUIRED str

        total_match_backfilled: (totalMatchBackfilled) REQUIRED int

        total_match_created: (totalMatchCreated) REQUIRED int

        total_match_to_backfill: (totalMatchToBackfill) REQUIRED int

        total_ticket_backfilled: (totalTicketBackfilled) REQUIRED int

        total_ticket_for_backfill: (totalTicketForBackfill) REQUIRED int

        total_ticket_for_match: (totalTicketForMatch) REQUIRED int

        total_ticket_in_queue: (totalTicketInQueue) REQUIRED int

        total_ticket_matched: (totalTicketMatched) REQUIRED int
    """

    # region fields

    pod_name: str  # REQUIRED
    tick_id: str  # REQUIRED
    timestamp: str  # REQUIRED
    total_match_backfilled: int  # REQUIRED
    total_match_created: int  # REQUIRED
    total_match_to_backfill: int  # REQUIRED
    total_ticket_backfilled: int  # REQUIRED
    total_ticket_for_backfill: int  # REQUIRED
    total_ticket_for_match: int  # REQUIRED
    total_ticket_in_queue: int  # REQUIRED
    total_ticket_matched: int  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_pod_name(self, value: str) -> ApimodelsXRayMatchPoolPodTickResult:
        self.pod_name = value
        return self

    def with_tick_id(self, value: str) -> ApimodelsXRayMatchPoolPodTickResult:
        self.tick_id = value
        return self

    def with_timestamp(self, value: str) -> ApimodelsXRayMatchPoolPodTickResult:
        self.timestamp = value
        return self

    def with_total_match_backfilled(
        self, value: int
    ) -> ApimodelsXRayMatchPoolPodTickResult:
        self.total_match_backfilled = value
        return self

    def with_total_match_created(
        self, value: int
    ) -> ApimodelsXRayMatchPoolPodTickResult:
        self.total_match_created = value
        return self

    def with_total_match_to_backfill(
        self, value: int
    ) -> ApimodelsXRayMatchPoolPodTickResult:
        self.total_match_to_backfill = value
        return self

    def with_total_ticket_backfilled(
        self, value: int
    ) -> ApimodelsXRayMatchPoolPodTickResult:
        self.total_ticket_backfilled = value
        return self

    def with_total_ticket_for_backfill(
        self, value: int
    ) -> ApimodelsXRayMatchPoolPodTickResult:
        self.total_ticket_for_backfill = value
        return self

    def with_total_ticket_for_match(
        self, value: int
    ) -> ApimodelsXRayMatchPoolPodTickResult:
        self.total_ticket_for_match = value
        return self

    def with_total_ticket_in_queue(
        self, value: int
    ) -> ApimodelsXRayMatchPoolPodTickResult:
        self.total_ticket_in_queue = value
        return self

    def with_total_ticket_matched(
        self, value: int
    ) -> ApimodelsXRayMatchPoolPodTickResult:
        self.total_ticket_matched = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "pod_name"):
            result["podName"] = str(self.pod_name)
        elif include_empty:
            result["podName"] = ""
        if hasattr(self, "tick_id"):
            result["tickId"] = str(self.tick_id)
        elif include_empty:
            result["tickId"] = ""
        if hasattr(self, "timestamp"):
            result["timestamp"] = str(self.timestamp)
        elif include_empty:
            result["timestamp"] = ""
        if hasattr(self, "total_match_backfilled"):
            result["totalMatchBackfilled"] = int(self.total_match_backfilled)
        elif include_empty:
            result["totalMatchBackfilled"] = 0
        if hasattr(self, "total_match_created"):
            result["totalMatchCreated"] = int(self.total_match_created)
        elif include_empty:
            result["totalMatchCreated"] = 0
        if hasattr(self, "total_match_to_backfill"):
            result["totalMatchToBackfill"] = int(self.total_match_to_backfill)
        elif include_empty:
            result["totalMatchToBackfill"] = 0
        if hasattr(self, "total_ticket_backfilled"):
            result["totalTicketBackfilled"] = int(self.total_ticket_backfilled)
        elif include_empty:
            result["totalTicketBackfilled"] = 0
        if hasattr(self, "total_ticket_for_backfill"):
            result["totalTicketForBackfill"] = int(self.total_ticket_for_backfill)
        elif include_empty:
            result["totalTicketForBackfill"] = 0
        if hasattr(self, "total_ticket_for_match"):
            result["totalTicketForMatch"] = int(self.total_ticket_for_match)
        elif include_empty:
            result["totalTicketForMatch"] = 0
        if hasattr(self, "total_ticket_in_queue"):
            result["totalTicketInQueue"] = int(self.total_ticket_in_queue)
        elif include_empty:
            result["totalTicketInQueue"] = 0
        if hasattr(self, "total_ticket_matched"):
            result["totalTicketMatched"] = int(self.total_ticket_matched)
        elif include_empty:
            result["totalTicketMatched"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        pod_name: str,
        tick_id: str,
        timestamp: str,
        total_match_backfilled: int,
        total_match_created: int,
        total_match_to_backfill: int,
        total_ticket_backfilled: int,
        total_ticket_for_backfill: int,
        total_ticket_for_match: int,
        total_ticket_in_queue: int,
        total_ticket_matched: int,
        **kwargs,
    ) -> ApimodelsXRayMatchPoolPodTickResult:
        instance = cls()
        instance.pod_name = pod_name
        instance.tick_id = tick_id
        instance.timestamp = timestamp
        instance.total_match_backfilled = total_match_backfilled
        instance.total_match_created = total_match_created
        instance.total_match_to_backfill = total_match_to_backfill
        instance.total_ticket_backfilled = total_ticket_backfilled
        instance.total_ticket_for_backfill = total_ticket_for_backfill
        instance.total_ticket_for_match = total_ticket_for_match
        instance.total_ticket_in_queue = total_ticket_in_queue
        instance.total_ticket_matched = total_ticket_matched
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelsXRayMatchPoolPodTickResult:
        instance = cls()
        if not dict_:
            return instance
        if "podName" in dict_ and dict_["podName"] is not None:
            instance.pod_name = str(dict_["podName"])
        elif include_empty:
            instance.pod_name = ""
        if "tickId" in dict_ and dict_["tickId"] is not None:
            instance.tick_id = str(dict_["tickId"])
        elif include_empty:
            instance.tick_id = ""
        if "timestamp" in dict_ and dict_["timestamp"] is not None:
            instance.timestamp = str(dict_["timestamp"])
        elif include_empty:
            instance.timestamp = ""
        if (
            "totalMatchBackfilled" in dict_
            and dict_["totalMatchBackfilled"] is not None
        ):
            instance.total_match_backfilled = int(dict_["totalMatchBackfilled"])
        elif include_empty:
            instance.total_match_backfilled = 0
        if "totalMatchCreated" in dict_ and dict_["totalMatchCreated"] is not None:
            instance.total_match_created = int(dict_["totalMatchCreated"])
        elif include_empty:
            instance.total_match_created = 0
        if (
            "totalMatchToBackfill" in dict_
            and dict_["totalMatchToBackfill"] is not None
        ):
            instance.total_match_to_backfill = int(dict_["totalMatchToBackfill"])
        elif include_empty:
            instance.total_match_to_backfill = 0
        if (
            "totalTicketBackfilled" in dict_
            and dict_["totalTicketBackfilled"] is not None
        ):
            instance.total_ticket_backfilled = int(dict_["totalTicketBackfilled"])
        elif include_empty:
            instance.total_ticket_backfilled = 0
        if (
            "totalTicketForBackfill" in dict_
            and dict_["totalTicketForBackfill"] is not None
        ):
            instance.total_ticket_for_backfill = int(dict_["totalTicketForBackfill"])
        elif include_empty:
            instance.total_ticket_for_backfill = 0
        if "totalTicketForMatch" in dict_ and dict_["totalTicketForMatch"] is not None:
            instance.total_ticket_for_match = int(dict_["totalTicketForMatch"])
        elif include_empty:
            instance.total_ticket_for_match = 0
        if "totalTicketInQueue" in dict_ and dict_["totalTicketInQueue"] is not None:
            instance.total_ticket_in_queue = int(dict_["totalTicketInQueue"])
        elif include_empty:
            instance.total_ticket_in_queue = 0
        if "totalTicketMatched" in dict_ and dict_["totalTicketMatched"] is not None:
            instance.total_ticket_matched = int(dict_["totalTicketMatched"])
        elif include_empty:
            instance.total_ticket_matched = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelsXRayMatchPoolPodTickResult]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelsXRayMatchPoolPodTickResult]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelsXRayMatchPoolPodTickResult,
        List[ApimodelsXRayMatchPoolPodTickResult],
        Dict[Any, ApimodelsXRayMatchPoolPodTickResult],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "podName": "pod_name",
            "tickId": "tick_id",
            "timestamp": "timestamp",
            "totalMatchBackfilled": "total_match_backfilled",
            "totalMatchCreated": "total_match_created",
            "totalMatchToBackfill": "total_match_to_backfill",
            "totalTicketBackfilled": "total_ticket_backfilled",
            "totalTicketForBackfill": "total_ticket_for_backfill",
            "totalTicketForMatch": "total_ticket_for_match",
            "totalTicketInQueue": "total_ticket_in_queue",
            "totalTicketMatched": "total_ticket_matched",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "podName": True,
            "tickId": True,
            "timestamp": True,
            "totalMatchBackfilled": True,
            "totalMatchCreated": True,
            "totalMatchToBackfill": True,
            "totalTicketBackfilled": True,
            "totalTicketForBackfill": True,
            "totalTicketForMatch": True,
            "totalTicketInQueue": True,
            "totalTicketMatched": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session History Service."""

__version__ = "1.9.4"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .query_acquiring_ds import QueryAcquiringDS
from .query_acquiring_ds_wait_a2982b import QueryAcquiringDSWaitTimeAvg
from .query_detail_tick_match_pool import QueryDetailTickMatchPool
from .query_detail_tick_match_f9b8b2 import QueryDetailTickMatchPoolMatches
from .query_detail_tick_match_d45948 import QueryDetailTickMatchPoolTicket
from .query_match_histories import QueryMatchHistories
from .query_match_length_durationp99 import QueryMatchLengthDurationp99
from .query_match_length_dura_0e6d44 import QueryMatchLengthDurationpAvg
from .query_match_ticket_histories import QueryMatchTicketHistories
from .query_total_active_session import QueryTotalActiveSession
from .query_total_matchmaking_49d09d import QueryTotalMatchmakingCanceled
from .query_total_matchmaking_73a209 import QueryTotalMatchmakingCreated
from .query_total_matchmaking_adaa30 import QueryTotalMatchmakingExpired
from .query_total_matchmaking_match import QueryTotalMatchmakingMatch
from .query_total_matchmaking_0ba5f3 import QueryTotalMatchmakingMatchTicket
from .query_total_player_persession import QueryTotalPlayerPersession
from .query_xray_match import QueryXrayMatch
from .query_xray_match_pool import QueryXrayMatchPool
from .query_xray_timeline_by__b9129e import QueryXrayTimelineByTicketID
from .query_xray_timeline_by_user_id import QueryXrayTimelineByUserID



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Session History Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ModelsSessionConfiguration(Model):
    """Models session configuration (models.SessionConfiguration)

    Properties:
        client_version: (ClientVersion) OPTIONAL str

        deployment: (Deployment) OPTIONAL str

        inactive_timeout: (InactiveTimeout) OPTIONAL int

        invite_timeout: (InviteTimeout) OPTIONAL int

        joinability: (Joinability) OPTIONAL str

        max_players: (MaxPlayers) OPTIONAL int

        min_players: (MinPlayers) OPTIONAL int

        persistent: (Persistent) OPTIONAL bool

        requested_regions: (RequestedRegions) OPTIONAL List[str]

        text_chat: (TextChat) OPTIONAL bool

        type_: (Type) OPTIONAL str
    """

    # region fields

    client_version: str  # OPTIONAL
    deployment: str  # OPTIONAL
    inactive_timeout: int  # OPTIONAL
    invite_timeout: int  # OPTIONAL
    joinability: str  # OPTIONAL
    max_players: int  # OPTIONAL
    min_players: int  # OPTIONAL
    persistent: bool  # OPTIONAL
    requested_regions: List[str]  # OPTIONAL
    text_chat: bool  # OPTIONAL
    type_: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_client_version(self, value: str) -> ModelsSessionConfiguration:
        self.client_version = value
        return self

    def with_deployment(self, value: str) -> ModelsSessionConfiguration:
        self.deployment = value
        return self

    def with_inactive_timeout(self, value: int) -> ModelsSessionConfiguration:
        self.inactive_timeout = value
        return self

    def with_invite_timeout(self, value: int) -> ModelsSessionConfiguration:
        self.invite_timeout = value
        return self

    def with_joinability(self, value: str) -> ModelsSessionConfiguration:
        self.joinability = value
        return self

    def with_max_players(self, value: int) -> ModelsSessionConfiguration:
        self.max_players = value
        return self

    def with_min_players(self, value: int) -> ModelsSessionConfiguration:
        self.min_players = value
        return self

    def with_persistent(self, value: bool) -> ModelsSessionConfiguration:
        self.persistent = value
        return self

    def with_requested_regions(self, value: List[str]) -> ModelsSessionConfiguration:
        self.requested_regions = value
        return self

    def with_text_chat(self, value: bool) -> ModelsSessionConfiguration:
        self.text_chat = value
        return self

    def with_type(self, value: str) -> ModelsSessionConfiguration:
        self.type_ = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "client_version"):
            result["ClientVersion"] = str(self.client_version)
        elif include_empty:
            result["ClientVersion"] = ""
        if hasattr(self, "deployment"):
            result["Deployment"] = str(self.deployment)
        elif include_empty:
            result["Deployment"] = ""
        if hasattr(self, "inactive_timeout"):
            result["InactiveTimeout"] = int(self.inactive_timeout)
        elif include_empty:
            result["InactiveTimeout"] = 0
        if hasattr(self, "invite_timeout"):
            result["InviteTimeout"] = int(self.invite_timeout)
        elif include_empty:
            result["InviteTimeout"] = 0
        if hasattr(self, "joinability"):
            result["Joinability"] = str(self.joinability)
        elif include_empty:
            result["Joinability"] = ""
        if hasattr(self, "max_players"):
            result["MaxPlayers"] = int(self.max_players)
        elif include_empty:
            result["MaxPlayers"] = 0
        if hasattr(self, "min_players"):
            result["MinPlayers"] = int(self.min_players)
        elif include_empty:
            result["MinPlayers"] = 0
        if hasattr(self, "persistent"):
            result["Persistent"] = bool(self.persistent)
        elif include_empty:
            result["Persistent"] = False
        if hasattr(self, "requested_regions"):
            result["RequestedRegions"] = [str(i0) for i0 in self.requested_regions]
        elif include_empty:
            result["RequestedRegions"] = []
        if hasattr(self, "text_chat"):
            result["TextChat"] = bool(self.text_chat)
        elif include_empty:
            result["TextChat"] = False
        if hasattr(self, "type_"):
            result["Type"] = str(self.type_)
        elif include_empty:
            result["Type"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        client_version: Optional[str] = None,
        deployment: Optional[str] = None,
        inactive_timeout: Optional[int] = None,
        invite_timeout: Optional[int] = None,
        joinability: Optional[str] = None,
        max_players: Optional[int] = None,
        min_players: Optional[int] = None,
        persistent: Optional[bool] = None,
        requested_regions: Optional[List[str]] = None,
        text_chat: Optional[bool] = None,
        type_: Optional[str] = None,
        **kwargs,
    ) -> ModelsSessionConfiguration:
        instance = cls()
        if client_version is not None:
            instance.client_version = client_version
        if deployment is not None:
            instance.deployment = deployment
        if inactive_timeout is not None:
            instance.inactive_timeout = inactive_timeout
        if invite_timeout is not None:
            instance.invite_timeout = invite_timeout
        if joinability is not None:
            instance.joinability = joinability
        if max_players is not None:
            instance.max_players = max_players
        if min_players is not None:
            instance.min_players = min_players
        if persistent is not None:
            instance.persistent = persistent
        if requested_regions is not None:
            instance.requested_regions = requested_regions
        if text_chat is not None:
            instance.text_chat = text_chat
        if type_ is not None:
            instance.type_ = type_
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsSessionConfiguration:
        instance = cls()
        if not dict_:
            return instance
        if "ClientVersion" in dict_ and dict_["ClientVersion"] is not None:
            instance.client_version = str(dict_["ClientVersion"])
        elif include_empty:
            instance.client_version = ""
        if "Deployment" in dict_ and dict_["Deployment"] is not None:
            instance.deployment = str(dict_["Deployment"])
        elif include_empty:
            instance.deployment = ""
        if "InactiveTimeout" in dict_ and dict_["InactiveTimeout"] is not None:
            instance.inactive_timeout = int(dict_["InactiveTimeout"])
        elif include_empty:
            instance.inactive_timeout = 0
        if "InviteTimeout" in dict_ and dict_["InviteTimeout"] is not None:
            instance.invite_timeout = int(dict_["InviteTimeout"])
        elif include_empty:
            instance.invite_timeout = 0
        if "Joinability" in dict_ and dict_["Joinability"] is not None:
            instance.joinability = str(dict_["Joinability"])
        elif include_empty:
            instance.joinability = ""
        if "MaxPlayers" in dict_ and dict_["MaxPlayers"] is not None:
            instance.max_players = int(dict_["MaxPlayers"])
        elif include_empty:
            instance.max_players = 0
        if "MinPlayers" in dict_ and dict_["MinPlayers"] is not None:
            instance.min_players = int(dict_["MinPlayers"])
        elif include_empty:
            instance.min_players = 0
        if "Persistent" in dict_ and dict_["Persistent"] is not None:
            instance.persistent = bool(dict_["Persistent"])
        elif include_empty:
            instance.persistent = False
        if "RequestedRegions" in dict_ and dict_["RequestedRegions"] is not None:
            instance.requested_regions = [str(i0) for i0 in dict_["RequestedRegions"]]
        elif include_empty:
            instance.requested_regions = []
        if "TextChat" in dict_ and dict_["TextChat"] is not None:
            instance.text_chat = bool(dict_["TextChat"])
        elif include_empty:
            instance.text_chat = False
        if "Type" in dict_ and dict_["Type"] is not None:
            instance.type_ = str(dict_["Type"])
        elif include_empty:
            instance.type_ = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsSessionConfiguration]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsSessionConfiguration]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsSessionConfiguration,
        List[ModelsSessionConfiguration],
        Dict[Any, ModelsSessionConfiguration],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "ClientVersion": "client_version",
            "Deployment": "deployment",
            "InactiveTimeout": "inactive_timeout",
            "InviteTimeout": "invite_timeout",
            "Joinability": "joinability",
            "MaxPlayers": "max_players",
            "MinPlayers": "min_players",
            "Persistent": "persistent",
            "RequestedRegions": "requested_regions",
            "TextChat": "text_chat",
            "Type": "type_",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "ClientVersion": False,
            "Deployment": False,
            "InactiveTimeout": False,
            "InviteTimeout": False,
            "Joinability": False,
            "MaxPlayers": False,
            "MinPlayers": False,
            "Persistent": False,
            "RequestedRegions": False,
            "TextChat": False,
            "Type": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as

from ..models import ApimodelsXRayAcquiringDsQueryResponse
from ..models import ApimodelsXRayAcquiringDsWaitTimeQueryResponse
from ..models import ApimodelsXRayCanceledMatchmakingTicketQueryResponse
from ..models import ApimodelsXRayCreatedMatchmakingTicketQueryResponse
from ..models import ApimodelsXRayExpiredMatchmakingTicketQueryResponse
from ..models import ApimodelsXRayMatchesQueryResponse
from ..models import ApimodelsXRayMatchHistorQueryResponse
from ..models import ApimodelsXRayMatchLengthDurationQueryResponse
from ..models import ApimodelsXRayMatchMatchmakingQueryResponse
from ..models import ApimodelsXRayMatchMatchmakingTicketQueryResponse
from ..models import ApimodelsXRayMatchPoolPodTickMatchResponse
from ..models import ApimodelsXRayMatchPoolPodTickQueryResponse
from ..models import ApimodelsXRayMatchPoolPodTickTicketResponse
from ..models import ApimodelsXRayMatchPoolQueryResponse
from ..models import ApimodelsXRayMatchTicketHistoryQueryResponse
from ..models import ApimodelsXRayTicketQueryResponse
from ..models import ApimodelsXRayTotalActiveSessionQueryResponse
from ..models import ApimodelsXRayTotalPlayerPersessionAVGQueryResponse
from ..models import ResponseError

from ..operations.x_ray import QueryAcquiringDS
from ..operations.x_ray import QueryAcquiringDSWaitTimeAvg
from ..operations.x_ray import QueryDetailTickMatchPool
from ..operations.x_ray import QueryDetailTickMatchPoolMatches
from ..operations.x_ray import QueryDetailTickMatchPoolTicket
from ..operations.x_ray import QueryMatchHistories
from ..operations.x_ray import QueryMatchLengthDurationp99
from ..operations.x_ray import QueryMatchLengthDurationpAvg
from ..operations.x_ray import QueryMatchTicketHistories
from ..operations.x_ray import QueryTotalActiveSession
from ..operations.x_ray import QueryTotalMatchmakingCanceled
from ..operations.x_ray import QueryTotalMatchmakingCreated
from ..operations.x_ray import QueryTotalMatchmakingExpired
from ..operations.x_ray import QueryTotalMatchmakingMatch
from ..operations.x_ray import QueryTotalMatchmakingMatchTicket
from ..operations.x_ray import QueryTotalPlayerPersession
from ..operations.x_ray import QueryXrayMatch
from ..operations.x_ray import QueryXrayMatchPool
from ..operations.x_ray import QueryXrayTimelineByTicketID
from ..operations.x_ray import QueryXrayTimelineByUserID


@same_doc_as(QueryAcquiringDS)
def query_acquiring_ds(
    end_date: str,
    start_date: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query total success and failed claim DS (queryAcquiringDS)

    Query total success and failed claim DS.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/acquiring-ds

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayAcquiringDsQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryAcquiringDS.create(
        end_date=end_date,
        start_date=start_date,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryAcquiringDS)
async def query_acquiring_ds_async(
    end_date: str,
    start_date: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query total success and failed claim DS (queryAcquiringDS)

    Query total success and failed claim DS.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/acquiring-ds

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayAcquiringDsQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryAcquiringDS.create(
        end_date=end_date,
        start_date=start_date,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryAcquiringDSWaitTimeAvg)
def query_acquiring_ds_wait_time_avg(
    end_date: str,
    start_date: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query acquiring ds wait time average (queryAcquiringDSWaitTimeAvg)

    Query acquiring ds wait time average. time in seconds

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/acquiring-ds-wait-time-avg

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayAcquiringDsWaitTimeQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryAcquiringDSWaitTimeAvg.create(
        end_date=end_date,
        start_date=start_date,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryAcquiringDSWaitTimeAvg)
async def query_acquiring_ds_wait_time_avg_async(
    end_date: str,
    start_date: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query acquiring ds wait time average (queryAcquiringDSWaitTimeAvg)

    Query acquiring ds wait time average. time in seconds

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/acquiring-ds-wait-time-avg

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayAcquiringDsWaitTimeQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryAcquiringDSWaitTimeAvg.create(
        end_date=end_date,
        start_date=start_date,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryDetailTickMatchPool)
def query_detail_tick_match_pool(
    end_date: str,
    pod_name: str,
    pool_name: str,
    start_date: str,
    all: Optional[bool] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray match pool ticks (queryDetailTickMatchPool)

    Query xray match pool ticks.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/match-pools/{poolName}/pods/{podName}/ticks

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        pod_name: (podName) REQUIRED str in path

        pool_name: (poolName) REQUIRED str in path

        all: (all) OPTIONAL bool in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayMatchPoolPodTickQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryDetailTickMatchPool.create(
        end_date=end_date,
        pod_name=pod_name,
        pool_name=pool_name,
        start_date=start_date,
        all=all,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryDetailTickMatchPool)
async def query_detail_tick_match_pool_async(
    end_date: str,
    pod_name: str,
    pool_name: str,
    start_date: str,
    all: Optional[bool] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray match pool ticks (queryDetailTickMatchPool)

    Query xray match pool ticks.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/match-pools/{poolName}/pods/{podName}/ticks

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        pod_name: (podName) REQUIRED str in path

        pool_name: (poolName) REQUIRED str in path

        all: (all) OPTIONAL bool in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayMatchPoolPodTickQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryDetailTickMatchPool.create(
        end_date=end_date,
        pod_name=pod_name,
        pool_name=pool_name,
        start_date=start_date,
        all=all,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryDetailTickMatchPoolMatches)
def query_detail_tick_match_pool_matches(
    pod_name: str,
    pool_name: str,
    tick_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray match pool tick matches by tick id (queryDetailTickMatchPoolMatches)

    Query xray match pool tick matches by tick id.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/match-pools/{poolName}/pods/{podName}/ticks/{tickId}/matches

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        pod_name: (podName) REQUIRED str in path

        pool_name: (poolName) REQUIRED str in path

        tick_id: (tickId) REQUIRED str in path

    Responses:
        200: OK - ApimodelsXRayMatchPoolPodTickMatchResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryDetailTickMatchPoolMatches.create(
        pod_name=pod_name,
        pool_name=pool_name,
        tick_id=tick_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryDetailTickMatchPoolMatches)
async def query_detail_tick_match_pool_matches_async(
    pod_name: str,
    pool_name: str,
    tick_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray match pool tick matches by tick id (queryDetailTickMatchPoolMatches)

    Query xray match pool tick matches by tick id.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/match-pools/{poolName}/pods/{podName}/ticks/{tickId}/matches

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        pod_name: (podName) REQUIRED str in path

        pool_name: (poolName) REQUIRED str in path

        tick_id: (tickId) REQUIRED str in path

    Responses:
        200: OK - ApimodelsXRayMatchPoolPodTickMatchResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryDetailTickMatchPoolMatches.create(
        pod_name=pod_name,
        pool_name=pool_name,
        tick_id=tick_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryDetailTickMatchPoolTicket)
def query_detail_tick_match_pool_ticket(
    pod_name: str,
    pool_name: str,
    tick_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray match pool tick tickets by tick id (queryDetailTickMatchPoolTicket)

    Query xray match pool tick tickets detail by tick id.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/match-pools/{poolName}/pods/{podName}/ticks/{tickId}/tickets

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        pod_name: (podName) REQUIRED str in path

        pool_name: (poolName) REQUIRED str in path

        tick_id: (tickId) REQUIRED str in path

    Responses:
        200: OK - ApimodelsXRayMatchPoolPodTickTicketResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryDetailTickMatchPoolTicket.create(
        pod_name=pod_name,
        pool_name=pool_name,
        tick_id=tick_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryDetailTickMatchPoolTicket)
async def query_detail_tick_match_pool_ticket_async(
    pod_name: str,
    pool_name: str,
    tick_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray match pool tick tickets by tick id (queryDetailTickMatchPoolTicket)

    Query xray match pool tick tickets detail by tick id.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/match-pools/{poolName}/pods/{podName}/ticks/{tickId}/tickets

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        pod_name: (podName) REQUIRED str in path

        pool_name: (poolName) REQUIRED str in path

        tick_id: (tickId) REQUIRED str in path

    Responses:
        200: OK - ApimodelsXRayMatchPoolPodTickTicketResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryDetailTickMatchPoolTicket.create(
        pod_name=pod_name,
        pool_name=pool_name,
        tick_id=tick_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryMatchHistories)
def query_match_histories(
    match_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray match histories (queryMatchHistories)

    Query xray match histories.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/matches/{matchId}/histories

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        match_id: (matchId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ApimodelsXRayMatchHistorQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryMatchHistories.create(
        match_id=match_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryMatchHistories)
async def query_match_histories_async(
    match_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray match histories (queryMatchHistories)

    Query xray match histories.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/matches/{matchId}/histories

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        match_id: (matchId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ApimodelsXRayMatchHistorQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryMatchHistories.create(
        match_id=match_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryMatchLengthDurationp99)
def query_match_length_durationp99(
    end_date: str,
    start_date: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query match length duration p99 (queryMatchLengthDurationp99)

    Query match length duration p99. time in seconds

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/match-length-duration-p99

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayMatchLengthDurationQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryMatchLengthDurationp99.create(
        end_date=end_date,
        start_date=start_date,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryMatchLengthDurationp99)
async def query_match_length_durationp99_async(
    end_date: str,
    start_date: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query match length duration p99 (queryMatchLengthDurationp99)

    Query match length duration p99. time in seconds

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/match-length-duration-p99

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayMatchLengthDurationQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryMatchLengthDurationp99.create(
        end_date=end_date,
        start_date=start_date,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryMatchLengthDurationpAvg)
def query_match_length_durationp_avg(
    end_date: str,
    start_date: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query match length duration avg (queryMatchLengthDurationpAvg)

    Query match length duration avg. time in seconds

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/match-length-duration-avg

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayMatchLengthDurationQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryMatchLengthDurationpAvg.create(
        end_date=end_date,
        start_date=start_date,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryMatchLengthDurationpAvg)
async def query_match_length_durationp_avg_async(
    end_date: str,
    start_date: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query match length duration avg (queryMatchLengthDurationpAvg)

    Query match length duration avg. time in seconds

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/match-length-duration-avg

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayMatchLengthDurationQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryMatchLengthDurationpAvg.create(
        end_date=end_date,
        start_date=start_date,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryMatchTicketHistories)
def query_match_ticket_histories(
    match_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray match ticket histories (queryMatchTicketHistories)

    Query xray match ticket histories.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/matches/{matchId}/ticket-histories

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        match_id: (matchId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelsXRayMatchTicketHistoryQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryMatchTicketHistories.create(
        match_id=match_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryMatchTicketHistories)
async def query_match_ticket_histories_async(
    match_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray match ticket histories (queryMatchTicketHistories)

    Query xray match ticket histories.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/matches/{matchId}/ticket-histories

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        match_id: (matchId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelsXRayMatchTicketHistoryQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryMatchTicketHistories.create(
        match_id=match_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryTotalActiveSession)
def query_total_active_session(
    end_date: str,
    start_date: str,
    region: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query total active session (queryTotalActiveSession)

    Query total active session.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/total-active-session

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        region: (region) OPTIONAL str in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayTotalActiveSessionQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryTotalActiveSession.create(
        end_date=end_date,
        start_date=start_date,
        region=region,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryTotalActiveSession)
async def query_total_active_session_async(
    end_date: str,
    start_date: str,
    region: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query total active session (queryTotalActiveSession)

    Query total active session.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/total-active-session

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        region: (region) OPTIONAL str in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayTotalActiveSessionQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryTotalActiveSession.create(
        end_date=end_date,
        start_date=start_date,
        region=region,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryTotalMatchmakingCanceled)
def query_total_matchmaking_canceled(
    end_date: str,
    start_date: str,
    match_pool: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query total ticket canceled (queryTotalMatchmakingCanceled)

    Query total ticket canceled.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/total-ticket-canceled

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        match_pool: (matchPool) OPTIONAL str in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayCanceledMatchmakingTicketQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryTotalMatchmakingCanceled.create(
        end_date=end_date,
        start_date=start_date,
        match_pool=match_pool,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryTotalMatchmakingCanceled)
async def query_total_matchmaking_canceled_async(
    end_date: str,
    start_date: str,
    match_pool: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query total ticket canceled (queryTotalMatchmakingCanceled)

    Query total ticket canceled.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/total-ticket-canceled

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        match_pool: (matchPool) OPTIONAL str in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayCanceledMatchmakingTicketQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryTotalMatchmakingCanceled.create(
        end_date=end_date,
        start_date=start_date,
        match_pool=match_pool,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryTotalMatchmakingCreated)
def query_total_matchmaking_created(
    end_date: str,
    start_date: str,
    match_pool: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query total ticket created (queryTotalMatchmakingCreated)

    Query total ticket created.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/total-ticket-created

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        match_pool: (matchPool) OPTIONAL str in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayCreatedMatchmakingTicketQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryTotalMatchmakingCreated.create(
        end_date=end_date,
        start_date=start_date,
        match_pool=match_pool,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryTotalMatchmakingCreated)
async def query_total_matchmaking_created_async(
    end_date: str,
    start_date: str,
    match_pool: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query total ticket created (queryTotalMatchmakingCreated)

    Query total ticket created.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/total-ticket-created

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        match_pool: (matchPool) OPTIONAL str in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayCreatedMatchmakingTicketQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryTotalMatchmakingCreated.create(
        end_date=end_date,
        start_date=start_date,
        match_pool=match_pool,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryTotalMatchmakingExpired)
def query_total_matchmaking_expired(
    end_date: str,
    start_date: str,
    match_pool: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query total ticket expired (queryTotalMatchmakingExpired)

    Query total ticket expired.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/total-ticket-expired

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        match_pool: (matchPool) OPTIONAL str in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayExpiredMatchmakingTicketQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryTotalMatchmakingExpired.create(
        end_date=end_date,
        start_date=start_date,
        match_pool=match_pool,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryTotalMatchmakingExpired)
async def query_total_matchmaking_expired_async(
    end_date: str,
    start_date: str,
    match_pool: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query total ticket expired (queryTotalMatchmakingExpired)

    Query total ticket expired.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/total-ticket-expired

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        match_pool: (matchPool) OPTIONAL str in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayExpiredMatchmakingTicketQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryTotalMatchmakingExpired.create(
        end_date=end_date,
        start_date=start_date,
        match_pool=match_pool,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryTotalMatchmakingMatch)
def query_total_matchmaking_match(
    end_date: str,
    start_date: str,
    match_pool: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query total match (queryTotalMatchmakingMatch)

    Query total match.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/total-match

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        match_pool: (matchPool) OPTIONAL str in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayMatchMatchmakingQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryTotalMatchmakingMatch.create(
        end_date=end_date,
        start_date=start_date,
        match_pool=match_pool,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryTotalMatchmakingMatch)
async def query_total_matchmaking_match_async(
    end_date: str,
    start_date: str,
    match_pool: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query total match (queryTotalMatchmakingMatch)

    Query total match.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/total-match

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        match_pool: (matchPool) OPTIONAL str in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayMatchMatchmakingQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryTotalMatchmakingMatch.create(
        end_date=end_date,
        start_date=start_date,
        match_pool=match_pool,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryTotalMatchmakingMatchTicket)
def query_total_matchmaking_match_ticket(
    end_date: str,
    start_date: str,
    match_pool: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query total ticket match (queryTotalMatchmakingMatchTicket)

    Query total ticket match.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/total-ticket-match

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        match_pool: (matchPool) OPTIONAL str in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayMatchMatchmakingTicketQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryTotalMatchmakingMatchTicket.create(
        end_date=end_date,
        start_date=start_date,
        match_pool=match_pool,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryTotalMatchmakingMatchTicket)
async def query_total_matchmaking_match_ticket_async(
    end_date: str,
    start_date: str,
    match_pool: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query total ticket match (queryTotalMatchmakingMatchTicket)

    Query total ticket match.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/total-ticket-match

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        match_pool: (matchPool) OPTIONAL str in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayMatchMatchmakingTicketQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryTotalMatchmakingMatchTicket.create(
        end_date=end_date,
        start_date=start_date,
        match_pool=match_pool,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryTotalPlayerPersession)
def query_total_player_persession(
    end_date: str,
    start_date: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query total player persession average (queryTotalPlayerPersession)

    Query total player persession average.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/total-player-persession-avg

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayTotalPlayerPersessionAVGQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryTotalPlayerPersession.create(
        end_date=end_date,
        start_date=start_date,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryTotalPlayerPersession)
async def query_total_player_persession_async(
    end_date: str,
    start_date: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query total player persession average (queryTotalPlayerPersession)

    Query total player persession average.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/metrics/total-player-persession-avg

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayTotalPlayerPersessionAVGQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryTotalPlayerPersession.create(
        end_date=end_date,
        start_date=start_date,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryXrayMatch)
def query_xray_match(
    match_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray timeline by matchID (queryXrayMatch)

    Query xray timeline by matchID.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/matches/{matchId}/tickets

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        match_id: (matchId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelsXRayMatchesQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryXrayMatch.create(
        match_id=match_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryXrayMatch)
async def query_xray_match_async(
    match_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray timeline by matchID (queryXrayMatch)

    Query xray timeline by matchID.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/matches/{matchId}/tickets

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        match_id: (matchId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelsXRayMatchesQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryXrayMatch.create(
        match_id=match_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryXrayMatchPool)
def query_xray_match_pool(
    end_date: str,
    pool_name: str,
    start_date: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray match pool (queryXrayMatchPool)

    Query xray match pool.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/match-pools/{poolName}

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        pool_name: (poolName) REQUIRED str in path

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayMatchPoolQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryXrayMatchPool.create(
        end_date=end_date,
        pool_name=pool_name,
        start_date=start_date,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryXrayMatchPool)
async def query_xray_match_pool_async(
    end_date: str,
    pool_name: str,
    start_date: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray match pool (queryXrayMatchPool)

    Query xray match pool.

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/match-pools/{poolName}

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        pool_name: (poolName) REQUIRED str in path

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayMatchPoolQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryXrayMatchPool.create(
        end_date=end_date,
        pool_name=pool_name,
        start_date=start_date,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryXrayTimelineByTicketID)
def query_xray_timeline_by_ticket_id(
    end_date: str,
    start_date: str,
    ticket_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray timeline (queryXrayTimelineByTicketID)

    Query xray timeline by ticketID

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/tickets/{ticketId}

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ticket_id: (ticketId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayTicketQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryXrayTimelineByTicketID.create(
        end_date=end_date,
        start_date=start_date,
        ticket_id=ticket_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryXrayTimelineByTicketID)
async def query_xray_timeline_by_ticket_id_async(
    end_date: str,
    start_date: str,
    ticket_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray timeline (queryXrayTimelineByTicketID)

    Query xray timeline by ticketID

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/tickets/{ticketId}

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ticket_id: (ticketId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayTicketQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryXrayTimelineByTicketID.create(
        end_date=end_date,
        start_date=start_date,
        ticket_id=ticket_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(QueryXrayTimelineByUserID)
def query_xray_timeline_by_user_id(
    end_date: str,
    start_date: str,
    user_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray timeline (queryXrayTimelineByUserID)

    Query xray timeline by userID or ticketID

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/users/{userId}/tickets

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayTicketQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryXrayTimelineByUserID.create(
        end_date=end_date,
        start_date=start_date,
        user_id=user_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(QueryXrayTimelineByUserID)
async def query_xray_timeline_by_user_id_async(
    end_date: str,
    start_date: str,
    user_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query xray timeline (queryXrayTimelineByUserID)

    Query xray timeline by userID or ticketID

    Properties:
        url: /sessionhistory/v2/admin/namespaces/{namespace}/xray/users/{userId}/tickets

        method: GET

        tags: ["XRay"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        end_date: (endDate) REQUIRED str in query

        start_date: (startDate) REQUIRED str in query

    Responses:
        200: OK - ApimodelsXRayTicketQueryResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = QueryXrayTimelineByUserID.create(
        end_date=end_date,
        start_date=start_date,
        user_id=user_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )
